PAWpySeed: density_ft Struct Reference

PAWpySeed Parallel C/Python package for numerical analysis of PAW DFT wavefunctions

- Main Page
- Classes
- Files

- Class List
- Class Index
- Class Hierarchy
- Class Members

Public Attributes | List of all members
density_ft Struct Reference

`#include <momentum.h>`

Collaboration diagram for density_ft:
[legend]

## Public Attributes
int | n1
int | l1
int | m1
int | n2
int | l2
int | m2
int | size
double * | ks
transform_spline_t * | transforms

## Member Data Documentation

double* density_ft::ks

int density_ft::l1

int density_ft::l2

int density_ft::m1

int density_ft::m2

int density_ft::n1

int density_ft::n2

int density_ft::size

transform_spline_t* density_ft::transforms

The documentation for this struct was generated from the following file:

- /home/kyle/Research/projects/pawpyseed/pawpyseed/core/momentum.h